/* screen.h */

#ifndef __SCREEN_H
#define __SCREEN_H

#include <curses.h>
#include <glib.h>

#include "filelist.h"
#include "playlist.h"
#include "player.h"

/* the help screen */
#define HELPTEXT  \
  "                                                                               \n" \
  "                             -=#  H E L P  #=-                                 \n" \
  "                                                                               \n" \
  "  Global                              Filelist                                 \n" \
  "  ------                              --------                                 \n" \
  "  Up, k, Down, j                      Space     : add file/dir/list to playlist\n" \
  "  PgUp, K, PgDown, J                  Enter     : chdir or play                \n" \
  "  Home, g, End, G                     Backspace : open parent dir              \n" \
  "              : movement              o         : open path                    \n" \
  "  Tab         : filelist/playlist     H, C      : open home/cdrom dir          \n" \
  "  n, p        : next/prev track                                                \n" \
  "  z, x        : toggle pause/stop     Playlist				  \n" \
  "  Left, Right,                        --------				  \n" \
  "  C-b, C-f    : seek                  Enter : play track			  \n" \
  "  t           : toggle counter        Space : toggle mark			  \n" \
  "  C-g, Esc    : cancel                a, c  : mark/clear all 		  \n" \
  "  0..9, +, -  : volume                A, C  : mark/clear regexp		  \n" \
  "  C-l         : refresh screen        m, d  : move/delete marked tracks	  \n" \
  "  h           : help                  r, R  : toggle repeat/Random mode	  \n" \
  "  q           : quit                  s, S  : shuffle/Sort playlist  	  \n" \
  "                                      w     : write playlist (to .m3u file)    \n" \
  "                                                                               \n"


typedef enum
{
   SCREEN_FILE,
   SCREEN_PLAY,
   SCREEN_HELP
} screen_mode;

typedef enum
{
   TIMER_NONE = 0,
   TIMER_FWD  = 1,
   TIMER_BWD  = 2,
   TIMER_LAST = 3
} timer_mode;

typedef struct
{
   WINDOW *fl, *fb, *pl, *pb, *h;
   gint lines, cols;
   
   FileListData *filelist;
   PlayListData *playlist;
   PlayerData *player;
   
   screen_mode mode;
   
   guint filepagesize;
   gint nfilestr;
   gint filesel;
   
   guint playpagesize;
   gint nplaystr;
   gint playsel;
   
   gint nplaycurr;
   gboolean repeat;
   gboolean random;
   
   gint nmsg;
   gchar *strbg;
   
   timer_mode timer;
   
   gint askpos;
} ScreenData;


ScreenData* screen_new();
void screen_set_player( ScreenData *data, PlayerData *player );
void screen_hardrefresh( ScreenData *data );
void screen_resize( ScreenData *data );
/* gchar* screen_ask( ScreenData *data, const char *quest ); */
void screen_ask_start( ScreenData *data, const gchar *quest );
gchar* screen_ask_getch( ScreenData *data );
void screen_message( ScreenData *data, gint timeout, const gchar *fmt, ... );
void screen_set_mode( ScreenData *data, screen_mode mode );
screen_mode screen_get_mode( ScreenData *data );
void screen_toggle_timer( ScreenData *data );


void screen_filelist_up( ScreenData *data );
void screen_filelist_down( ScreenData *data );
void screen_filelist_pageup( ScreenData *data );
void screen_filelist_pagedown( ScreenData *data );
void screen_filelist_home( ScreenData *data );
void screen_filelist_end( ScreenData *data );

void screen_filelist_select( ScreenData *data );
void screen_filelist_mark( ScreenData *data );
void screen_filelist_chng_dir( ScreenData *data, const char* dirname );

void screen_playlist_up( ScreenData *data );
void screen_playlist_down( ScreenData *data );
void screen_playlist_pageup( ScreenData *data );
void screen_playlist_pagedown( ScreenData *data );
void screen_playlist_home( ScreenData *data );
void screen_playlist_end( ScreenData *data );

void screen_playlist_select( ScreenData *data );
void screen_playlist_mark( ScreenData *data );
void screen_playlist_mark_all( ScreenData *data );
void screen_playlist_unmark_all( ScreenData *data );
void screen_playlist_mark_reg( ScreenData *data, const gchar *regex );
void screen_playlist_unmark_reg( ScreenData *data, const gchar *regex );
void screen_playlist_delete( ScreenData *data );
void screen_playlist_move( ScreenData *data );
void screen_playlist_shuffle( ScreenData *data );
void screen_playlist_sort( ScreenData *data );
void screen_playlist_toggle_repeat( ScreenData *data );
void screen_playlist_toggle_random( ScreenData *data );
void screen_playlist_write( ScreenData *data, gchar *filename );
gint screen_playlist_add_unknown( ScreenData *data, const gchar *filename );

void screen_player_stop( ScreenData *data );
void screen_player_toggle_pause( ScreenData *data );
void screen_player_next( ScreenData *data );
void screen_player_prev( ScreenData *data );
void screen_player_seek( ScreenData *data, gdouble seconds );

#endif /* __SCREEN_H */
